<?php

/**
 * @file
 * UI pages for revisions, similar with pages from node.pages.inc.
 */

/**
 * Generate an overview table of older revisions of a taxonomy term.
 *
 * @param $viewed_term
 *  The term for which the revisions are listed.
 */
function taxonomy_revision_overview($viewed_term) {
  drupal_set_title(t('Revisions for %title', array('%title' => $viewed_term->name)), PASS_THROUGH);

  $header = array(t('Revision'), array('data' => t('Operations'), 'colspan' => 2));

  $revisions = taxonomy_revision_list($viewed_term);
  $rows = array();
  $revert_permission = FALSE;
  $delete_permission = FALSE;
  if (user_access('revert taxonomy term revisions') || user_access('administer taxonomy')) {
    $revert_permission = TRUE;
  }
  if (user_access('delete taxonomy term revisions') || user_access('administer taxonomy')) {
    $delete_permission = TRUE;
  }

  foreach ($revisions as $revision) {
    $row = array();
    $operations = array();
    if ($revision->revision_id == $viewed_term->revision_id) {
      $row[] = array(
        'data' => t('!date by !username', array(
          '!date' => l(format_date($revision->timestamp, 'short'), "taxonomy/term/$viewed_term->tid"),
          '!username' => theme('username', array('account' => user_load($revision->uid))),
        )) . (($revision->log != '') ? '<p class="revision-log">' . filter_xss($revision->log) . '</p>' : ''),
        'class' => array('revision-current'),
      );
      $operations[] = array(
        'data' => drupal_placeholder(t('current revision')),
        'class' => array('revision-current'),
        'colspan' => 2,
      );
    }
    else {
      $row[] = t('!date by !username', array(
        '!date' => l(format_date($revision->timestamp, 'short'), "taxonomy/term/$viewed_term->tid/revisions/$revision->revision_id/view"),
        '!username' => theme('username', array('account' => user_load($revision->uid))),
      )) . (($revision->log != '') ? '<p class="revision-log">' . filter_xss($revision->log) . '</p>' : '');
      if ($revert_permission) {
        $operations[] = l(t('revert'), "taxonomy/term/$viewed_term->tid/revisions/$revision->revision_id/revert");
      }
      else {
        // Empty row for theming purposes.
        $operations[] = "";
      }
      if ($delete_permission) {
        $operations[] = l(t('delete'), "taxonomy/term/$viewed_term->tid/revisions/$revision->revision_id/delete");
      }
      else {
        // Empty row for theming purposes.
        $operations[] = "";
      }
    }
    $rows[] = array_merge($row, $operations);
  }

  $build['taxonomy_term_revisions_table'] = array(
    '#theme' => 'table',
    '#rows' => $rows,
    '#header' => $header,
  );

  return $build;
}

/**
 * Form builder for taxonomy term revision revert form.
 *
 * @ingroup forms
 * @see taxonomy_revision_revert_confirm_submit()
 */
function taxonomy_revision_revert_confirm($form, $form_state, $term_revision) {
  $form['#term_revision'] = $term_revision;
  return confirm_form($form, t('Are you sure you want to revert to the revision from %revision-date?', array('%revision-date' => format_date($term_revision->timestamp))), 'taxonomy/term/' . $term_revision->tid . '/revisions', '', t('Revert'), t('Cancel'));
}

/**
 * Submit handler for the taxonomy revision revert form. Reverts taxonomy term
 * to a previous revision.
 *
 * @see taxonomy_revision_revert_confirm()
 */
function taxonomy_revision_revert_confirm_submit($form, &$form_state) {
  $term_revision = $form['#term_revision'];
  $term_revision->revision = 1;
  $term_revision->log = t('Copy of the revision from %date.', array('%date' => format_date($term_revision->timestamp)));
  taxonomy_term_save($term_revision);
  watchdog('taxonomy_revision', 'reverted %title revision %revision.', array('%title' => $term_revision->name, '%revision' => $term_revision->revision_id));
  drupal_set_message(t('%title has been reverted back to the revision from %revision-date.', array('%title' => $term_revision->name, '%revision-date' => format_date($term_revision->timestamp))));
  $form_state['redirect'] = 'taxonomy/term/' . $term_revision->tid . '/revisions';
}

/**
 * Form builder for a revision confirm for term deletion.
 */
function taxonomy_revision_delete_confirm($form, $form_state, $term_revision) {
  $form['#term_revision'] = $term_revision;
  return confirm_form($form, t('Are you sure you want to delete the revision from %revision-date?', array('%revision-date' => format_date($term_revision->timestamp))), 'taxonomy/term/' . $term_revision->tid . '/revisions', t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Submit handler for the taxonomy revision delete form. Deletes a taxonomy term
 * revision.
 *
 * @see taxonomy_revision_delete_confirm()
 */
function taxonomy_revision_delete_confirm_submit($form, &$form_state) {
  $term_revision = $form['#term_revision'];
  taxonomy_revision_delete($term_revision);

  watchdog('taxonomy_revision', 'deleted %title revision %revision.', array('%title' => $term_revision->name, '%revision' => $term_revision->revision_id));
  drupal_set_message(t('Revision from %revision-date %title has been deleted.', array('%revision-date' => format_date($term_revision->timestamp), '%title' => $term_revision->name)));
  $form_state['redirect'] = 'taxonomy/term/' . $term_revision->tid;
  if (db_query('SELECT COUNT(revision_id) FROM {taxonomy_term_data_revision} WHERE tid = :tid', array(':tid' => $term_revision->tid))->fetchField() > 1) {
    $form_state['redirect'] .= '/revisions';
  }
}
